# -*- text -*-
# first non-comment line must be the short description:
Utilities library with several more or less independent components

This library is mainly intended for myself, so I can access it from
anywhere. But anyone else is welcome to have a look. Documentation
is still lacking, I know, but that shall change. Testing is better.

The full documentation (well, what already exists of it) for this
version is at
<https://git.w21.org/ni/jpylib/-/blob/v$__package_version$/README.md>

[ni@w21.org 2020-08-09]
